@@ -8,9 +8,9 @@
 # なんらかの原因で正常に行われなかった場合、終了ステータスとして 0 以外を返します。
 # 
 
-require 'languages-statistics'
+require './languages-statistics'
 
-$stderr.puts 'Console encoding set in config.xml: ' + Config.new.console_encoding
+$stderr.puts 'Console encoding set in config.xml: ' + WikiBotConfig.new.console_encoding
 processor = LanguageResourcePrinter.new
 processor.execute
 exit(processor.status)
