@@ -9,9 +9,9 @@
 # なんらかの原因で処理が中断した場合、終了ステータスとして 0 以外を返します。
 # 
 
-require 'languages-statistics'
+require './languages-statistics'
 
-$stderr.puts 'Console encoding set in config.xml: ' + Config.new.console_encoding
+$stderr.puts 'Console encoding set in config.xml: ' + WikiBotConfig.new.console_encoding
 
 taker = Taker.new
 taker.execute
